"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _eventstoreBase = require("@resolve-js/eventstore-base");

var _initReplicationStateTable = _interopRequireDefault(require("./init-replication-state-table"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const setReplicationStatus = async (pool, status, statusData, lastEvent) => {
  const {
    database,
    escapeId,
    escape
  } = pool;
  const replicationStateTableName = await (0, _initReplicationStateTable.default)(pool);
  const batchInProgress = 'batchInProgress';

  try {
    await database.exec(`
    ${status === batchInProgress ? `WITH "AlreadyInProgressCheck" AS (SELECT ABS("AlreadyInProcess") AS "AlreadyInProcess" FROM (
      SELECT 0 AS "AlreadyInProcess"
    UNION ALL
      SELECT -9223372036854775808 AS "AlreadyInProcess"
      FROM ${escapeId(replicationStateTableName)}
      WHERE "Status" = ${escape(batchInProgress)}
    ))` : ``}
    UPDATE ${escapeId(replicationStateTableName)} 
    SET
      "Status" = ${escape(status)},
      "StatusData" = ${statusData != null ? escape(JSON.stringify(statusData)) : 'NULL'}
      ${lastEvent != null ? `, "SuccessEvent" = ${escape(JSON.stringify(lastEvent))}` : ``} ${status === batchInProgress ? `WHERE (SELECT COUNT("AlreadyInProcess") FROM "AlreadyInProgressCheck") = 1` : ``}`);
  } catch (error) {
    const errorMessage = error != null && error.message != null ? error.message : '';

    if (errorMessage === 'SQLITE_ERROR: integer overflow') {
      throw new _eventstoreBase.ReplicationAlreadyInProgress();
    } else {
      throw error;
    }
  }
};

var _default = setReplicationStatus;
exports.default = _default;
//# sourceMappingURL=set-replication-status.js.map